jactorch.functional.loglinear
=============================

.. automodule:: jactorch.functional.loglinear

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      batch_logmatmulexp
      log1mexp
      logaddexp
      logits_and
      logits_or
      logmatmulexp
      logsumexp
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: batch_logmatmulexp

.. autofunction:: log1mexp

.. autofunction:: logaddexp

.. autofunction:: logits_and

.. autofunction:: logits_or

.. autofunction:: logmatmulexp

.. autofunction:: logsumexp


